==> film_gyaan-1.0.1.tar.gz: lib/src/dx/_endpoints/objects/release_dates.dart <==
// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class ReleaseDates extends Result {
  ReleaseDates({
    required this.id,
    required this.results,
  });

  factory ReleaseDates.fromJson(String str) => ReleaseDates.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory ReleaseDates.fromMap(Map<String, dynamic> json) => ReleaseDates(
        id: json['id'] as int? ?? 0,
        results: List<ReleaseDatesResult>.from(
          (json['results'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => ReleaseDatesResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  String toJson() => json.encode(toMap());

  int id;
  List<ReleaseDatesResult> results;

  Map<String, dynamic> toMap() => <String, dynamic>{
        'id': id,
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class ReleaseDatesResult {
  ReleaseDatesResult({
    required this.iso31661,
    required this.releaseDates,
  });

  factory ReleaseDatesResult.fromJson(String str) =>
      ReleaseDatesResult.fromMap(json.decode(str) as Map<String, dynamic>);

  factory ReleaseDatesResult.fromMap(Map<String, dynamic> json) =>
      ReleaseDatesResult(
        iso31661: json['iso_3166_1'] as String? ?? '',
        releaseDates: List<ReleaseDate>.from(
          (json['release_dates'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => ReleaseDate.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  String toJson() => json.encode(toMap());

  String iso31661;
  List<ReleaseDate> releaseDates;

  Map<String, dynamic> toMap() => <String, dynamic>{
        'iso_3166_1': iso31661,
        'release_dates': List<Map<String, dynamic>>.from(
          releaseDates.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class ReleaseDate {
  ReleaseDate({
    required this.certification,
    required this.iso6391,
    required this.note,
    required this.releaseDate,
    required this.type,
  });

  factory ReleaseDate.fromJson(String str) => ReleaseDate.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory ReleaseDate.fromMap(Map<String, dynamic> json) => ReleaseDate(
        certification: json['certification'] as String? ?? '',
        iso6391: json['iso_639_1'] as String? ?? '',
        note: json['note'] as String? ?? '',
        releaseDate: DateTime.tryParse(
          json['release_date'] as String? ?? '',
        ),
        type: json['type'] as int? ?? 0,
      );

  String certification;
  String iso6391;
  String note;
  DateTime? releaseDate;
  int type;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'certification': certification,
        'iso_639_1': iso6391,
        'note': note,
        'release_date':
            releaseDate?.toIso8601String(),
        'type': type,
      };
}

==> film_gyaan-1.0.3.tar.gz: lib/src/dx/_endpoints/objects/release_dates.dart <==
// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

/// @nodoc
class ReleaseDates extends Result {
  ReleaseDates({
    required this.id,
    required this.results,
  });

  factory ReleaseDates.fromJson(String str) => ReleaseDates.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory ReleaseDates.fromMap(Map<String, dynamic> json) => ReleaseDates(
        id: json['id'] as int? ?? 0,
        results: List<ReleaseDatesResult>.from(
          (json['results'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => ReleaseDatesResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  String toJson() => json.encode(toMap());

  int id;
  List<ReleaseDatesResult> results;

  Map<String, dynamic> toMap() => <String, dynamic>{
        'id': id,
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class ReleaseDatesResult {
  ReleaseDatesResult({
    required this.iso31661,
    required this.releaseDates,
  });

  factory ReleaseDatesResult.fromJson(String str) =>
      ReleaseDatesResult.fromMap(json.decode(str) as Map<String, dynamic>);

  factory ReleaseDatesResult.fromMap(Map<String, dynamic> json) =>
      ReleaseDatesResult(
        iso31661: json['iso_3166_1'] as String? ?? '',
        releaseDates: List<ReleaseDate>.from(
          (json['release_dates'] as List<dynamic>? ?? <dynamic>[]).map<dynamic>(
            (dynamic x) => ReleaseDate.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  String toJson() => json.encode(toMap());

  String iso31661;
  List<ReleaseDate> releaseDates;

  Map<String, dynamic> toMap() => <String, dynamic>{
        'iso_3166_1': iso31661,
        'release_dates': List<Map<String, dynamic>>.from(
          releaseDates.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class ReleaseDate {
  ReleaseDate({
    required this.certification,
    required this.iso6391,
    required this.note,
    required this.releaseDate,
    required this.type,
  });

  factory ReleaseDate.fromJson(String str) => ReleaseDate.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory ReleaseDate.fromMap(Map<String, dynamic> json) => ReleaseDate(
        certification: json['certification'] as String? ?? '',
        iso6391: json['iso_639_1'] as String? ?? '',
        note: json['note'] as String? ?? '',
        releaseDate: DateTime.tryParse(
          json['release_date'] as String? ?? '',
        ),
        type: json['type'] as int? ?? 0,
      );

  String certification;
  String iso6391;
  String note;
  DateTime? releaseDate;
  int type;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'certification': certification,
        'iso_639_1': iso6391,
        'note': note,
        'release_date': releaseDate?.toIso8601String(),
        'type': type,
      };
}
